import Vue from 'vue';
import App from '@/App.vue';
import router from '@/router';
import ElementUI from 'element-ui';
import '@/styles/index.scss'
import VueI18n from 'vue-i18n';
import { messages } from '@/i18n';
import 'babel-polyfill';
import '@/libs/resize';
import api from '@/api';
import store from '@/store'
import {post,get,del,put} from '@/plugins/requests/index.js';
import { systemStatus, systemTypeStatus, systemAttributionStatus, courseTypeStatus, hoursStatus, roleStatus, orderTypeFn, orderStatusFn, orderNatureFn, Percentage, removeByValue, formatDate, isIE, successMsg, warningMsg, errorMsg } from './libs/core';
import permission from '@/router/permission';
import Setting from '@/setting';

// 插件
import plugins from '@/plugins';

Vue.use(plugins);

Vue.prototype.api = api;
Vue.prototype.$get = get;
Vue.prototype.$post = post;
Vue.prototype.$del = del;
Vue.prototype.$put = put;

Vue.prototype.systemStatus = systemStatus;
Vue.prototype.systemTypeStatus = systemTypeStatus;
Vue.prototype.systemAttributionStatus = systemAttributionStatus;
Vue.prototype.courseTypeStatus = courseTypeStatus;
Vue.prototype.hoursStatus = hoursStatus;
Vue.prototype.roleStatus = roleStatus;
Vue.prototype.orderTypeFn = orderTypeFn;
Vue.prototype.orderStatusFn = orderStatusFn;
Vue.prototype.orderNatureFn = orderNatureFn;
Vue.prototype.Percentage = Percentage;
Vue.prototype.removeByValue = removeByValue;
Vue.prototype.formatDate = formatDate;
Vue.prototype.isIE = isIE;
Vue.prototype.successMsg = successMsg;
Vue.prototype.warningMsg = warningMsg;
Vue.prototype.errorMsg = errorMsg;

Vue.config.productionTip = false;
Vue.use(VueI18n);
Vue.use(ElementUI);
const i18n = new VueI18n({
    locale: Setting.i18n.default,
    messages
});

new Vue({
    router,
    store,
    i18n,
    render: h => h(App)
}).$mount('#app');
